/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIWebBrowser.idl"
#include "nsIBaseWindow.idl"
#include "nsIScrollable.idl"
#include "nsITextScroll.idl"

/*
nsCWebBrowser implements:
-------------------------
nsIWebBrowser
nsIDocShellTreeItem
nsIWebNavigation
nsIWebProgress
nsIBaseWindow
nsIScrollable
nsITextScroll
nsIInterfaceRequestor


Outwardly communicates with:
----------------------------
nsIWebBrowserChrome
nsIBaseWindow
nsIInterfaceRequestor
*/

%{ C++
#include "nsEmbedCID.h"
%}
